@@ -3,6 +3,7 @@
  *		salvo option by: Chuck A DeGaul
  * with improved user interface, autoconfiguration and code cleanup
  *		by Eric S. Raymond <esr@snark.thyrsus.com>
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
 #include <curses.h>
@@ -429,7 +430,7 @@ static void initgame(void)
 	/* get a command letter */
 	prompt(1, "Type one of [%s] to pick a ship.", docked+1);
 	do {
-	    c = getcoord(PLAYER);
+	    c = toupper(getcoord(PLAYER));
 	} while
 	    (!strchr(docked, c));
 
